pub unsafe fn raise_fd_limit()Expand description
darwin_fd_limit exists to work around an issue where launchctl on macOS defaults the rlimit maxfiles to 256/unlimited. The default soft limit of 256 ends up being far too low for our multithreaded scheduler testing, depending on the number of cores available.
This fixes issue #7772.